Elastic Beanstalk — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »

# Elastic Beanstalk

## boto.beanstalk

`boto.beanstalk.` `connect_to_region`(region_name, **kw_params)

`boto.beanstalk.` `regions`()

  Get all available regions for the AWS Elastic Beanstalk service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.beanstalk.layer1

class `boto.beanstalk.layer1.` `Layer1`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, proxy_user=None, proxy_pass=None, debug=0, https_connection_factory=None, region=None, path='/', api_version=None, security_token=None, profile_name=None)
  `APIVersion` = '2010-12-01'
  `DefaultRegionEndpoint` = 'elasticbeanstalk.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `check_dns_availability`(cname_prefix)

    Checks if the specified CNAME is available.

    Parameters: | cname_prefix (string) – The prefix used when this CNAME is reserved.

  `create_application`(application_name, description=None)

    Creates an application that has one configuration template named default and no application versions.

    Parameters: | application_name (string) – The name of the application. Constraint: This name must be unique within your account. If the specified name already exists, the action returns an InvalidParameterValue error. description (string) – Describes the application.
    Raises : | TooManyApplicationsException

  `create_application_version`(application_name, version_label, description=None, s3_bucket=None, s3_key=None, auto_create_application=None)

    Creates an application version for the specified application.

    Parameters: | application_name (string) – The name of the application. If no application is found with this name, and AutoCreateApplication is false, returns an InvalidParameterValue error. version_label (string) – A label identifying this version. Constraint: Must be unique per application. If an application version already exists with this label for the specified application, AWS Elastic Beanstalk returns an InvalidParameterValue error. description (string) – Describes this version. s3_bucket (string) – The Amazon S3 bucket where the data is located. s3_key (string) – The Amazon S3 key where the data is located. Both s3_bucket and s3_key must be specified in order to use a specific source bundle. If both of these values are not specified the sample application will be used. auto_create_application (boolean) – Determines how the system behaves if the specified application for this version does not already exist: true: Automatically creates the specified application for this version if it does not already exist. false: Returns an InvalidParameterValue if the specified application for this version does not already exist. Default: false Valid Values: true | false
    Raises : | TooManyApplicationsException, TooManyApplicationVersionsException, InsufficientPrivilegesException, S3LocationNotInServiceRegionException

  `create_configuration_template`(application_name, template_name, solution_stack_name=None, source_configuration_application_name=None, source_configuration_template_name=None, environment_id=None, description=None, option_settings=None)

    Creates a configuration template.

    Templates are associated with a specific application and are used to deploy different versions of the application with the same configuration settings.

    Parameters: | application_name (string) – The name of the application to associate with this configuration template. If no application is found with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error. template_name (string) – The name of the configuration template. Constraint: This name must be unique per application. Default: If a configuration template already exists with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error. solution_stack_name (string) – The name of the solution stack used by this configuration. The solution stack specifies the operating system, architecture, and application server for a configuration template. It determines the set of configuration options as well as the possible and default values. Use ListAvailableSolutionStacks to obtain a list of available solution stacks. Default: If the SolutionStackName is not specified and the source configuration parameter is blank, AWS Elastic Beanstalk uses the default solution stack. If not specified and the source configuration parameter is specified, AWS Elastic Beanstalk uses the same solution stack as the source configuration template. source_configuration_application_name (string) – The name of the application associated with the configuration. source_configuration_template_name (string) – The name of the configuration template. environment_id (string) – The ID of the environment used with this configuration template. description (string) – Describes this configuration. option_settings (list) – If specified, AWS Elastic Beanstalk sets the specified configuration option to the requested value. The new value overrides the value obtained from the solution stack or the source configuration template.
    Raises : | InsufficientPrivilegesException, TooManyConfigurationTemplatesException

  `create_environment`(application_name, environment_name, version_label=None, template_name=None, solution_stack_name=None, cname_prefix=None, description=None, option_settings=None, options_to_remove=None, tier_name=None, tier_type=None, tier_version='1.0')

    Launches an environment for the application using a configuration.

    - Parameters: | application_name (string) – The name of the application that contains the version to be deployed. If no application is found with this name, CreateEnvironment returns an InvalidParameterValue error. environment_name (string) – A unique name for the deployment environment. Used in the application URL. Constraint: Must be from 4 to 23 characters in length. The name can contain only letters, numbers, and hyphens. It cannot start or end with a hyphen. This name must be unique in your account. If the specified name already exists, AWS Elastic Beanstalk returns an InvalidParameterValue error. Default: If the CNAME parameter is not specified, the environment name becomes part of the CNAME, and therefore part of the visible URL for your application. version_label (string) – The name of the application version to deploy. If the specified application has no associated application versions, AWS Elastic Beanstalk UpdateEnvironment returns an InvalidParameterValue error. Default: If not specified, AWS Elastic Beanstalk attempts to launch the most recently created application version. template_name (string) – The name of the configuration template to use in deployment. If no configuration template is found with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error. Condition: You must specify either this parameter or a SolutionStackName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error. solution_stack_name (string) – This is an alternative to specifying a configuration name. If specified, AWS Elastic Beanstalk sets the configuration values to the default values associated with the specified solution stack. Condition: You must specify either this or a TemplateName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error. cname_prefix (string) – If specified, the environment attempts to use this value as the prefix for the CNAME. If not specified, the environment uses the environment name. description (string) – Describes this environment. option_settings (list) – If specified, AWS Elastic Beanstalk sets the specified configuration options to the requested value in the configuration set for the new environment. These override the values obtained from the solution stack or the configuration template. Each element in the list is a tuple of (Namespace, OptionName, Value), for example:
          [('aws:autoscaling:launchconfiguration',
              'Ec2KeyName', 'mykeypair')]
    options_to_remove (list) – A list of custom user-defined configuration options to remove from the configuration set for this new environment. tier_name (string) – The name of the tier. Valid values are “WebServer” and “Worker”. Defaults to “WebServer”. The `tier_name` and a `tier_type` parameters are related and the values provided must be valid. The possible combinations are: “WebServer” and “Standard” (the default) “Worker” and “SQS/HTTP” tier_type (string) – The type of the tier. Valid values are “Standard” if `tier_name` is “WebServer” and “SQS/HTTP” if `tier_name` is “Worker”. Defaults to “Standard”.
    Raises : | TooManyEnvironmentsException, InsufficientPrivilegesException

  `create_storage_location`()

    Creates the Amazon S3 storage location for the account. This location is used to store user log files.

    Raises : | TooManyBucketsException, S3SubscriptionRequiredException, InsufficientPrivilegesException

  `delete_application`(application_name, terminate_env_by_force=None)

    Deletes the specified application along with all associated versions and configurations. The application versions will not be deleted from your Amazon S3 bucket.

    Parameters: | application_name (string) – The name of the application to delete. terminate_env_by_force (boolean) – When set to true, running environments will be terminated before deleting the application.
    Raises : | OperationInProgressException

  `delete_application_version`(application_name, version_label, delete_source_bundle=None)

    Deletes the specified version from the specified application.

    Parameters: | application_name (string) – The name of the application to delete releases from. version_label (string) – The label of the version to delete. delete_source_bundle (boolean) – Indicates whether to delete the associated source bundle from Amazon S3. Valid Values: true | false
    Raises : | SourceBundleDeletionException, InsufficientPrivilegesException, OperationInProgressException, S3LocationNotInServiceRegionException

  `delete_configuration_template`(application_name, template_name)

    Deletes the specified configuration template.

    Parameters: | application_name (string) – The name of the application to delete the configuration template from. template_name (string) – The name of the configuration template to delete.
    Raises : | OperationInProgressException

  `delete_environment_configuration`(application_name, environment_name)

    Deletes the draft configuration associated with the running environment. Updating a running environment with any configuration changes creates a draft configuration set. You can get the draft configuration using DescribeConfigurationSettings while the update is in progress or if the update fails. The DeploymentStatus for the draft configuration indicates whether the deployment is in process or has failed. The draft configuration remains in existence until it is deleted with this action.

    Parameters: | application_name (string) – The name of the application the environment is associated with. environment_name (string) – The name of the environment to delete the draft configuration from.

  `describe_application_versions`(application_name=None, version_labels=None)

    Returns descriptions for existing application versions.

    Parameters: | application_name (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to only include ones that are associated with the specified application. version_labels (list) – If specified, restricts the returned descriptions to only include ones that have the specified version labels.

  `describe_applications`(application_names=None)

    Returns the descriptions of existing applications.

    Parameters: | application_names (list) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to only include those with the specified names.

  `describe_configuration_options`(application_name=None, template_name=None, environment_name=None, solution_stack_name=None, options=None)

    Describes configuration options used in a template or environment.

    Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines. The description includes the values the options, their default values, and an indication of the required action on a running environment if an option value is changed.

    Parameters: | application_name (string) – The name of the application associated with the configuration template or environment. Only needed if you want to describe the configuration options associated with either the configuration template or environment. template_name (string) – The name of the configuration template whose configuration options you want to describe. environment_name (string) – The name of the environment whose configuration options you want to describe. solution_stack_name (string) – The name of the solution stack whose configuration options you want to describe. options (list) – If specified, restricts the descriptions to only the specified options.

  `describe_configuration_settings`(application_name, template_name=None, environment_name=None)

    Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment. When describing the settings for the configuration set associated with a running environment, it is possible to receive two sets of setting descriptions. One is the deployed configuration set, and the other is a draft configuration of an environment that is either in the process of deployment or that failed to deploy.

    Parameters: | application_name (string) – The application for the environment or configuration template. template_name (string) – The name of the configuration template to describe. Conditional: You must specify either this parameter or an EnvironmentName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error. environment_name (string) – The name of the environment to describe. Condition: You must specify either this or a TemplateName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

  `describe_environment_resources`(environment_id=None, environment_name=None)

    Returns AWS resources for this environment.

    Parameters: | environment_id (string) – The ID of the environment to retrieve AWS resource usage data. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment to retrieve AWS resource usage data. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
    Raises : | InsufficientPrivilegesException

  `describe_environments`(application_name=None, version_label=None, environment_ids=None, environment_names=None, include_deleted=None, included_deleted_back_to=None)

    Returns descriptions for existing environments.

    Parameters: | application_name (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application. version_label (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version. environment_ids (list) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs. environment_names (list) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names. include_deleted (boolean) – Indicates whether to include deleted environments: true: Environments that have been deleted after IncludedDeletedBackTo are displayed. false: Do not include deleted environments. included_deleted_back_to (timestamp) – If specified when IncludeDeleted is set to true, then environments deleted after this date are displayed.

  `describe_events`(application_name=None, version_label=None, template_name=None, environment_id=None, environment_name=None, request_id=None, severity=None, start_time=None, end_time=None, max_records=None, next_token=None)

    Returns event descriptions matching criteria up to the last 6 weeks.

    Parameters: | application_name (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those associated with this application. version_label (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this application version. template_name (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that are associated with this environment configuration. environment_id (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment. environment_name (string) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment. request_id (string) – If specified, AWS Elastic Beanstalk restricts the described events to include only those associated with this request ID. severity (string) – If specified, limits the events returned from this call to include only those with the specified severity or higher. start_time (timestamp) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur on or after this time. end_time (timestamp) – If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur up to, but not including, the EndTime. max_records (integer) – Specifies the maximum number of events that can be returned, beginning with the most recent event. next_token (string) – Pagination token. If specified, the events return the next batch of results.

  `list_available_solution_stacks`()

    Returns a list of the available solution stack names.

  `rebuild_environment`(environment_id=None, environment_name=None)

    Deletes and recreates all of the AWS resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.

    Parameters: | environment_id (string) – The ID of the environment to rebuild. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment to rebuild. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
    Raises : | InsufficientPrivilegesException

  `request_environment_info`(info_type='tail', environment_id=None, environment_name=None)

    Initiates a request to compile the specified type of information of the deployed environment. Setting the InfoType to tail compiles the last lines from the application server log files of every Amazon EC2 instance in your environment. Use RetrieveEnvironmentInfo to access the compiled information.

    Parameters: | info_type (string) – The type of information to request. environment_id (string) – The ID of the environment of the requested data. If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment of the requested data. If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

  `restart_app_server`(environment_id=None, environment_name=None)

    Causes the environment to restart the application container server running on each Amazon EC2 instance.

    Parameters: | environment_id (string) – The ID of the environment to restart the server for. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment to restart the server for. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

  `retrieve_environment_info`(info_type='tail', environment_id=None, environment_name=None)

    Retrieves the compiled information from a RequestEnvironmentInfo request.

    Parameters: | info_type (string) – The type of information to retrieve. environment_id (string) – The ID of the data’s environment. If no such environment is found, returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the data’s environment. If no such environment is found, returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.

  `swap_environment_cnames`(source_environment_id=None, source_environment_name=None, destination_environment_id=None, destination_environment_name=None)

    Swaps the CNAMEs of two environments.

    Parameters: | source_environment_id (string) – The ID of the source environment. Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName. You may also specify both. If you specify the SourceEnvironmentId, you must specify the DestinationEnvironmentId. source_environment_name (string) – The name of the source environment. Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName. You may also specify both. If you specify the SourceEnvironmentName, you must specify the DestinationEnvironmentName. destination_environment_id (string) – The ID of the destination environment. Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName. You may also specify both. You must specify the SourceEnvironmentId with the DestinationEnvironmentId. destination_environment_name (string) – The name of the destination environment. Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName. You may also specify both. You must specify the SourceEnvironmentName with the DestinationEnvironmentName.

  `terminate_environment`(environment_id=None, environment_name=None, terminate_resources=None)

    Terminates the specified environment.

    Parameters: | environment_id (string) – The ID of the environment to terminate. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment to terminate. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. terminate_resources (boolean) – Indicates whether the associated AWS resources should shut down when the environment is terminated: true: (default) The user AWS resources (for example, the Auto Scaling group, LoadBalancer, etc.) are terminated along with the environment. false: The environment is removed from the AWS Elastic Beanstalk but the AWS resources continue to operate. For more information, see the AWS Elastic Beanstalk User Guide. Default: true Valid Values: true | false
    Raises : | InsufficientPrivilegesException

  `update_application`(application_name, description=None)

    Updates the specified application to have the specified properties.

    Parameters: | application_name (string) – The name of the application to update. If no such application is found, UpdateApplication returns an InvalidParameterValue error. description (string) – A new description for the application. Default: If not specified, AWS Elastic Beanstalk does not update the description.

  `update_application_version`(application_name, version_label, description=None)

    Updates the application version to have the properties.

    Parameters: | application_name (string) – The name of the application associated with this version. If no application is found with this name, UpdateApplication returns an InvalidParameterValue error. version_label (string) – The name of the version to update. If no application version is found with this label, UpdateApplication returns an InvalidParameterValue error. description (string) – A new description for this release.

  `update_configuration_template`(application_name, template_name, description=None, option_settings=None, options_to_remove=None)

    Updates the specified configuration template to have the specified properties or configuration option values.

    Parameters: | application_name (string) – The name of the application associated with the configuration template to update. If no application is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error. template_name (string) – The name of the configuration template to update. If no configuration template is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error. description (string) – A new description for the configuration. option_settings (list) – A list of configuration option settings to update with the new specified option value. options_to_remove (list) – A list of configuration options to remove from the configuration set. Constraint: You can remove only UserDefined configuration options.
    Raises : | InsufficientPrivilegesException

  `update_environment`(environment_id=None, environment_name=None, version_label=None, template_name=None, description=None, option_settings=None, options_to_remove=None, tier_name=None, tier_type=None, tier_version='1.0')

    Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment. Attempting to update both the release and configuration is not allowed and AWS Elastic Beanstalk returns an InvalidParameterCombination error. When updating the configuration settings to a new template or individual settings, a draft configuration is created and DescribeConfigurationSettings for this environment returns two setting descriptions with different DeploymentStatus values.

    Parameters: | environment_id (string) – The ID of the environment to update. If no environment with this ID exists, AWS Elastic Beanstalk returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. environment_name (string) – The name of the environment to update. If no environment with this name exists, AWS Elastic Beanstalk returns an InvalidParameterValue error. Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. version_label (string) – If this parameter is specified, AWS Elastic Beanstalk deploys the named application version to the environment. If no such application version is found, returns an InvalidParameterValue error. template_name (string) – If this parameter is specified, AWS Elastic Beanstalk deploys this configuration template to the environment. If no such configuration template is found, AWS Elastic Beanstalk returns an InvalidParameterValue error. description (string) – If this parameter is specified, AWS Elastic Beanstalk updates the description of this environment. option_settings (list) – If specified, AWS Elastic Beanstalk updates the configuration set associated with the running environment and sets the specified configuration options to the requested value. options_to_remove (list) – A list of custom user-defined configuration options to remove from the configuration set for this environment. tier_name (string) – The name of the tier. Valid values are “WebServer” and “Worker”. Defaults to “WebServer”. The `tier_name` and a `tier_type` parameters are related and the values provided must be valid. The possible combinations are: “WebServer” and “Standard” (the default) “Worker” and “SQS/HTTP” tier_type (string) – The type of the tier. Valid values are “Standard” if `tier_name` is “WebServer” and “SQS/HTTP” if `tier_name` is “Worker”. Defaults to “Standard”.
    Raises : | InsufficientPrivilegesException

  `validate_configuration_settings`(application_name, option_settings, template_name=None, environment_name=None)

    Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid. This action returns a list of messages indicating any errors or warnings associated with the selection of option values.

    Parameters: | application_name (string) – The name of the application that the configuration template or environment belongs to. template_name (string) – The name of the configuration template to validate the settings against. Condition: You cannot specify both this and an environment name. environment_name (string) – The name of the environment to validate the settings against. Condition: You cannot specify both this and a configuration template name. option_settings (list) – A list of the options and desired values to evaluate.
    Raises : | InsufficientPrivilegesException

## boto.beanstalk.response

Classify responses from layer1 and strict type values.

class `boto.beanstalk.response.` `ApplicationDescription`(response)

class `boto.beanstalk.response.` `ApplicationVersionDescription`(response)

class `boto.beanstalk.response.` `AutoScalingGroup`(response)

class `boto.beanstalk.response.` `BaseObject`

class `boto.beanstalk.response.` `CheckDNSAvailabilityResponse`(response)

class `boto.beanstalk.response.` `CheckDnsAvailabilityResponse`(response)

class `boto.beanstalk.response.` `ConfigurationOptionDescription`(response)

class `boto.beanstalk.response.` `ConfigurationOptionSetting`(response)

class `boto.beanstalk.response.` `ConfigurationSettingsDescription`(response)

class `boto.beanstalk.response.` `CreateApplicationResponse`(response)

class `boto.beanstalk.response.` `CreateApplicationVersionResponse`(response)

class `boto.beanstalk.response.` `CreateConfigurationTemplateResponse`(response)

class `boto.beanstalk.response.` `CreateEnvironmentResponse`(response)

class `boto.beanstalk.response.` `CreateStorageLocationResponse`(response)

class `boto.beanstalk.response.` `DeleteApplicationResponse`(response)

class `boto.beanstalk.response.` `DeleteApplicationVersionResponse`(response)

class `boto.beanstalk.response.` `DeleteConfigurationTemplateResponse`(response)

class `boto.beanstalk.response.` `DeleteEnvironmentConfigurationResponse`(response)

class `boto.beanstalk.response.` `DescribeApplicationVersionsResponse`(response)

class `boto.beanstalk.response.` `DescribeApplicationsResponse`(response)

class `boto.beanstalk.response.` `DescribeConfigurationOptionsResponse`(response)

class `boto.beanstalk.response.` `DescribeConfigurationSettingsResponse`(response)

class `boto.beanstalk.response.` `DescribeEnvironmentResourcesResponse`(response)

class `boto.beanstalk.response.` `DescribeEnvironmentsResponse`(response)

class `boto.beanstalk.response.` `DescribeEventsResponse`(response)

class `boto.beanstalk.response.` `EnvironmentDescription`(response)

class `boto.beanstalk.response.` `EnvironmentInfoDescription`(response)

class `boto.beanstalk.response.` `EnvironmentResourceDescription`(response)

class `boto.beanstalk.response.` `EnvironmentResourcesDescription`(response)

class `boto.beanstalk.response.` `EventDescription`(response)

class `boto.beanstalk.response.` `Instance`(response)

class `boto.beanstalk.response.` `LaunchConfiguration`(response)

class `boto.beanstalk.response.` `ListAvailableSolutionStacksResponse`(response)

class `boto.beanstalk.response.` `Listener`(response)

class `boto.beanstalk.response.` `LoadBalancer`(response)

class `boto.beanstalk.response.` `LoadBalancerDescription`(response)

class `boto.beanstalk.response.` `OptionRestrictionRegex`(response)

class `boto.beanstalk.response.` `RebuildEnvironmentResponse`(response)

class `boto.beanstalk.response.` `RequestEnvironmentInfoResponse`(response)

class `boto.beanstalk.response.` `Response`(response)

class `boto.beanstalk.response.` `ResponseMetadata`(response)

class `boto.beanstalk.response.` `RestartAppServerResponse`(response)

class `boto.beanstalk.response.` `RetrieveEnvironmentInfoResponse`(response)

class `boto.beanstalk.response.` `S3Location`(response)

class `boto.beanstalk.response.` `SolutionStackDescription`(response)

class `boto.beanstalk.response.` `SwapEnvironmentCNAMEsResponse`(response)

class `boto.beanstalk.response.` `SwapEnvironmentCnamesResponse`(response)

class `boto.beanstalk.response.` `TerminateEnvironmentResponse`(response)

class `boto.beanstalk.response.` `Trigger`(response)

class `boto.beanstalk.response.` `UpdateApplicationResponse`(response)

class `boto.beanstalk.response.` `UpdateApplicationVersionResponse`(response)

class `boto.beanstalk.response.` `UpdateConfigurationTemplateResponse`(response)

class `boto.beanstalk.response.` `UpdateEnvironmentResponse`(response)

class `boto.beanstalk.response.` `ValidateConfigurationSettingsResponse`(response)

class `boto.beanstalk.response.` `ValidationMessage`(response)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »